{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "autoskewer",
            "doc": "detect and trim adapter sequences from reads\n>autoskewer.py -t <runtime.tmpdir> -i <input> -o <outName> -l <outLog>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "autoskewer.log",
            "stderr": "autoskewer.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input sequence file",
                    "format": [
                        "#autoskewer.tool.cwl/input/FileFormats.cv.yamlfastq",
                        "#autoskewer.tool.cwl/input/FileFormats.cv.yamlfasta"
                    ],
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#autoskewer.tool.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional output trimmed log",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#autoskewer.tool.cwl/outLog"
                },
                {
                    "type": "string",
                    "doc": "Output trimmed sequences",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#autoskewer.tool.cwl/outName"
                }
            ],
            "baseCommand": "autoskewer.py",
            "arguments": [
                {
                    "prefix": "-t",
                    "valueFrom": "$(runtime.tmpdir)"
                }
            ],
            "id": "#autoskewer.tool.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#autoskewer.tool.cwl/error",
                    "outputBinding": {
                        "glob": "autoskewer.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#autoskewer.tool.cwl/info",
                    "outputBinding": {
                        "glob": "autoskewer.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output trimmed sequences",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#autoskewer.tool.cwl/outTrim"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Optional output trimmed log file",
                    "outputBinding": {
                        "glob": "$(inputs.outLog)"
                    },
                    "id": "#autoskewer.tool.cwl/trimLog"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "fastq-mcf",
            "doc": "fastq quality trimmer\n>fastq-mcf 'n/a' <input> -S -k 0 -l <minLength> --max-ns <maxLqb> -q <minQual> -w <window> -o <outName>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "fastq-mcf.log",
            "stderr": "fastq-mcf.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input fastq sequence file",
                    "format": [
                        "#fastq-mcf.tool.cwl/input/FileFormats.cv.yamlfastq"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#fastq-mcf.tool.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Maxmium N-calls in a read, default 5",
                    "default": 5,
                    "inputBinding": {
                        "prefix": "--max-ns"
                    },
                    "id": "#fastq-mcf.tool.cwl/maxLqb"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Minimum remaining sequence length, default 50",
                    "default": 50,
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#fastq-mcf.tool.cwl/minLength"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Quality threshold causing base removal, default 15",
                    "default": 15,
                    "inputBinding": {
                        "prefix": "-q"
                    },
                    "id": "#fastq-mcf.tool.cwl/minQual"
                },
                {
                    "type": "string",
                    "doc": "Output name",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#fastq-mcf.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Window-size for quality trimming, default 10",
                    "default": 10,
                    "inputBinding": {
                        "prefix": "-w"
                    },
                    "id": "#fastq-mcf.tool.cwl/window"
                }
            ],
            "baseCommand": [
                "fastq-mcf"
            ],
            "arguments": [
                {
                    "position": 0,
                    "valueFrom": "n/a"
                },
                {
                    "valueFrom": "-S"
                },
                {
                    "prefix": "-k",
                    "valueFrom": "0"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#fastq-mcf.tool.cwl/error",
                    "outputBinding": {
                        "glob": "fastq-mcf.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#fastq-mcf.tool.cwl/info",
                    "outputBinding": {
                        "glob": "fastq-mcf.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output skipped fastq sequences",
                    "outputBinding": {
                        "glob": "$(inputs.outName).skip"
                    },
                    "id": "#fastq-mcf.tool.cwl/outSkip"
                },
                {
                    "type": "File",
                    "doc": "Output trimmed fastq sequences",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#fastq-mcf.tool.cwl/outTrim"
                }
            ],
            "id": "#fastq-mcf.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "seqUtil",
            "doc": "Utility tool for various sequence file transformations.\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "seqUtil.log",
            "stderr": "seqUtil.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Return fasta with each sequence truncated to 1024 bps",
                    "inputBinding": {
                        "prefix": "--bowtie_truncate"
                    },
                    "id": "#seqUtil.tool.cwl/bowtieTruncate"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to tabbed",
                    "inputBinding": {
                        "prefix": "--fasta2tab"
                    },
                    "id": "#seqUtil.tool.cwl/fasta2tab"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fastq to fasta",
                    "inputBinding": {
                        "prefix": "--fastq2fasta"
                    },
                    "id": "#seqUtil.tool.cwl/fastq2fasta"
                },
                {
                    "type": "string",
                    "doc": "Output sequence file",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#seqUtil.tool.cwl/output"
                },
                {
                    "type": "File",
                    "doc": "Input sequence file",
                    "format": [
                        "#seqUtil.tool.cwl/sequences/FileFormats.cv.yamlfastq",
                        "#seqUtil.tool.cwl/sequences/FileFormats.cv.yamlfasta"
                    ],
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#seqUtil.tool.cwl/sequences"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Sort fasta file by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to ID list, sorted by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid2id"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid2id"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to tabbed, sorted by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid2tab"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid2tab"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "List of sequences to subset input by, required with subsetSeqs option",
                    "inputBinding": {
                        "prefix": "--list"
                    },
                    "id": "#seqUtil.tool.cwl/subsetList"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Return fasta with each sequence truncated to 1024 bps",
                    "inputBinding": {
                        "prefix": "--subset_seqs"
                    },
                    "id": "#seqUtil.tool.cwl/subsetSeqs"
                }
            ],
            "baseCommand": [
                "seqUtil"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#seqUtil.tool.cwl/error",
                    "outputBinding": {
                        "glob": "seqUtil.error"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#seqUtil.tool.cwl/file"
                },
                {
                    "type": "File",
                    "id": "#seqUtil.tool.cwl/info",
                    "outputBinding": {
                        "glob": "seqUtil.log"
                    }
                }
            ],
            "id": "#seqUtil.tool.cwl"
        },
        {
            "class": "Workflow",
            "label": "preprocess fastq",
            "doc": "Remove and trim low quality reads from fastq files. \nReturn fasta files with reads passed and reads removed.\n",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/jobid"
                },
                {
                    "type": "int",
                    "default": 5,
                    "id": "#main/maxLqb"
                },
                {
                    "type": "int",
                    "default": 30,
                    "id": "#main/minLength"
                },
                {
                    "type": "int",
                    "default": 15,
                    "id": "#main/minQual"
                },
                {
                    "type": "File",
                    "id": "#main/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/passed2fasta/file",
                    "id": "#main/passed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/removed2fasta/file",
                    "id": "#main/removed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/adapterTrim/outTrim",
                    "id": "#main/trimmed"
                }
            ],
            "steps": [
                {
                    "run": "#autoskewer.tool.cwl",
                    "in": [
                        {
                            "source": "#main/sequences",
                            "id": "#main/adapterTrim/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).080.adapter.trim.passed.fastq",
                            "id": "#main/adapterTrim/outName"
                        }
                    ],
                    "out": [
                        "#main/adapterTrim/outTrim"
                    ],
                    "id": "#main/adapterTrim"
                },
                {
                    "run": "#fastq-mcf.tool.cwl",
                    "in": [
                        {
                            "source": "#main/adapterTrim/outTrim",
                            "id": "#main/filter/input"
                        },
                        {
                            "source": "#main/maxLqb",
                            "id": "#main/filter/maxLqb"
                        },
                        {
                            "source": "#main/minLength",
                            "id": "#main/filter/minLength"
                        },
                        {
                            "source": "#main/minQual",
                            "id": "#main/filter/minQual"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).100.preprocess.fastq",
                            "id": "#main/filter/outName"
                        }
                    ],
                    "out": [
                        "#main/filter/outTrim",
                        "#main/filter/outSkip"
                    ],
                    "id": "#main/filter"
                },
                {
                    "run": "#seqUtil.tool.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/passed2fasta/fastq2fasta"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).100.preprocess.passed.fna",
                            "id": "#main/passed2fasta/output"
                        },
                        {
                            "source": "#main/filter/outTrim",
                            "id": "#main/passed2fasta/sequences"
                        }
                    ],
                    "out": [
                        "#main/passed2fasta/file"
                    ],
                    "id": "#main/passed2fasta"
                },
                {
                    "run": "#seqUtil.tool.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/removed2fasta/fastq2fasta"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).100.preprocess.removed.fna",
                            "id": "#main/removed2fasta/output"
                        },
                        {
                            "source": "#main/filter/outSkip",
                            "id": "#main/removed2fasta/sequences"
                        }
                    ],
                    "out": [
                        "#main/removed2fasta/file"
                    ],
                    "id": "#main/removed2fasta"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
